@@ -31,8 +31,6 @@
 #include <kcalcore/alarm.h>
 #include <kcalcore/memorycalendar.h>
 
-#include <kmessagebox.h>
-
 #include <klocalizedstring.h>
 #include "kalarmcal_debug.h"
 
@@ -417,7 +415,7 @@ Type type(const QString &mimeType)
 
 Types types(const QStringList &mimeTypes)
 {
-    Types types = nullptr;
+    Types types = 0;
     for (const QString &type : mimeTypes) {
         if (type == MIME_ACTIVE) {
             types |= ACTIVE;
@@ -455,3 +453,5 @@ QStringList mimeTypes(Types types)
 } // namespace CalEvent
 
 } // namespace KAlarmCal
+
+// vim: et sw=4:
